Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Crocker <dcrocker@eschertech.com>2021-01-23 17:13:42 +0300
committerDavid Crocker <dcrocker@eschertech.com>2021-01-23 17:13:42 +0300
commit679be2794bddb1a8e044dbc3eab882ef159bf8e1 (patch)
treecf428b5564065f38ad9248fe05a804a16c6f0c28 /src/RepRap.cpp
parent8aac0fd4cbec408adcb4b1df71c2513daf476caf (diff)
Initial implementation of G17/G18/G19 (not tested)
Diffstat (limited to 'src/RepRap.cpp')
-rw-r--r--src/RepRap.cpp10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/RepRap.cpp b/src/RepRap.cpp
index aa0d453e..06e47c4d 100644
--- a/src/RepRap.cpp
+++ b/src/RepRap.cpp
@@ -1200,18 +1200,24 @@ GCodeResult RepRap::SetAllToolsFirmwareRetraction(GCodeBuffer& gb, const StringR
return rslt;
}
// Get the current axes used as X axes
AxesBitmap RepRap::GetCurrentXAxes() const noexcept
{
return Tool::GetXAxes(currentTool);
}
// Get the current axes used as Y axes
AxesBitmap RepRap::GetCurrentYAxes() const noexcept
{
return Tool::GetYAxes(currentTool);
}
+// Get the current axes used as the specified axis
+AxesBitmap RepRap::GetCurrentAxisMapping(unsigned int axis) const noexcept
+{
+ return Tool::GetAxisMapping(currentTool, axis);
+}
+
// Set the previous tool number. Inline because it is only called from one place.
void RepRap::SetPreviousToolNumber() noexcept
{
@@ -1200,18 +1200,24 @@ GCodeResult RepRap::SetAllToolsFirmwareRetraction(GCodeBuffer& gb, const StringR
return rslt;
}
-// Get the current axes used as X axes
+// Get the current axes used as X axis
AxesBitmap RepRap::GetCurrentXAxes() const noexcept
{
@@ -1200,18 +1200,24 @@ GCodeResult RepRap::SetAllToolsFirmwareRetraction(GCodeBuffer& gb, const StringR
return Tool::GetXAxes(currentTool);
}
-// Get the current axes used as Y axes
+// Get the current axes used as Y axis
AxesBitmap RepRap::GetCurrentYAxes() const noexcept
{